``flask_admin.contrib.peewee``
==============================

Peewee model backend implementation.

.. automodule:: flask_admin.contrib.peewee

    .. autoclass:: ModelView
        :members:
        :inherited-members:
        :exclude-members: column_filters, filter_converter, model_form_converter,
                          inline_model_form_converter, fast_mass_delete, inline_models

        Class inherits configuration options from :class:`~flask_admin.model.BaseModelView` and they're not displayed here.

        .. autoattribute:: column_filters
        .. autoattribute:: filter_converter
        .. autoattribute:: model_form_converter
        .. autoattribute:: inline_model_form_converter
        .. autoattribute:: fast_mass_delete
        .. autoattribute:: inline_models
